package de.intevation.flys.client.shared.model;

/**
 * @author <a href="mailto:bjoern.ricks@intevation.de">Björn Ricks</a>
 */
public class DefaultMeasurementStation implements MeasurementStation {

    private String  name;
    private Double  start;
    private Double  end;
    private Double  station;
    private String  rivername;
    private String  measurementtype;
    private String  riverside;
    private Integer id;
    private boolean kmup;
    private String  moperator;

    public DefaultMeasurementStation() {
    }

    public DefaultMeasurementStation(
            String  rivername,
            String  name,
            Integer id,
            Double  station,
            Double  start,
            Double  end,
            boolean kmup,
            String  riverside,
            String  measurementtype,
            String  moperator)
    {
        this.rivername       = rivername;
        this.name            = name;
        this.station         = station;
        this.start           = start;
        this.end             = end;
        this.riverside       = riverside;
        this.measurementtype = measurementtype;
        this.id              = id;
        this.kmup            = kmup;
        this.moperator       = moperator;
    }

    /**
     * Returns the name of the measurement station
     */
    @Override
    public String getName() {
        return this.name;
    }

    /**
     * Returns the start KM of the measurement station or null if not available
     */
    @Override
    public Double getKmStart() {
        return this.start;
    }

    /**
     * Returns the end KM of the measurement station or null if not available
     */
    @Override
    public Double getKmEnd() {
        return this.end;
    }

    /**
     * Returns the river to which this measurement station belongs
     */
    @Override
    public String getRiverName() {
        return this.rivername;
    }

    /**
     * Returns the type of the measurement station
     */
    @Override
    public String getMeasurementType() {
        return this.measurementtype;
    }

    /**
     * Returns the station km of this measurement station
     */
    @Override
    public Double getStation() {
        return this.station;
    }


    /**
     * Returns the side of the river where this measurement station belongs
     */
    @Override
    public String getRiverSide() {
        return this.riverside;
    }

    /**
     * Returns the ID of the measurement station
     */
    @Override
    public Integer getID() {
        return this.id;
    }

    @Override
    public boolean isKmUp() {
        return this.kmup;
    }

    /**
     * Returns the operator of the measurement station
     */
    @Override
    public String getOperator() {
        return this.moperator;
    }
}
